@@ -1,11 +1,11 @@
 package Package::props ;
-$VERSION = 2.21 ;
+$VERSION = 2.30 ;
 use 5.006_001 ;
 use strict ;
 
 ; use Class::props
 ; our @ISA = qw| Class::props |
-   
+
 ; 1
 
 __END__
@@ -89,38 +89,46 @@ From the directory where this file is located, type:
 
 =head1 DESCRIPTION
 
-This pragma is very similar to the C<Class::props> pragma: the main difference is the underlying variable that holds the value, which is a global scalar in the caller package instead in the class. For example:
+This pragma is very similar to the C<Class::props> pragma: the main
+difference is the underlying variable that holds the value, which is
+a global scalar in the caller package instead in the class. For example:
 
    package BaseClass;
    use Package::props 'a_package_prop';
    use Class::props 'a_class_prop';
-   
+
    package SubClass;
    our @ISA = 'BaseClass';
-   
+
    # underlaying scalar for accessor 'a_package_prop' is
    # $BaseClass::a_package_prop
    # underlaying scalar for accessor 'a_class_prop' is
    # $SubClass::a_class_prop;
 
-This might seem a subtle difference, but the possible usage in inherited classes makes a big difference.
+This might seem a subtle difference, but the possible usage in inherited classes
+makes a big difference.
 
-You can also call a package property accessor by statically using the implementing package name (e.g. C<BaseClass->a_prop>), regardless the subclass that uses it.
+You can also call a package property accessor by statically using the implementing
+package name (e.g. C<BaseClass->a_prop>), regardless the subclass that uses it.
 
-See the documentation of the accessor properties in L<Class::props> for all the details.
+See the documentation of the accessor properties in L<Class::props>
+for all the details.
 
 =head1 SUPPORT and FEEDBACK
 
-If you need support or if you want just to send me some feedback or request, please use this link: http://perl.4pro.net/?Object::props.
+If you need support or if you want just to send me some feedback or
+request, please use this link: http://perl.4pro.net/?Object::props.
 
 =head1 AUTHOR and COPYRIGHT
 
  2004-2005 by Domizio Demichelis.
 
-All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as perl itself.
+All Rights Reserved. This module is free software. It may be used, redistributed
+and/or modified under the same terms as perl itself.
 
 =head1 CREDITS
 
-Thanks to Juerd Waalboer (http://search.cpan.org/author/JUERD) that with its I<Attribute::Property> inspired the creation of this distribution.
+Thanks to Juerd Waalboer (http://search.cpan.org/author/JUERD) that with its
+I<Attribute::Property> inspired the creation of this distribution.
 
 =cut
